@@ -108,7 +108,7 @@
 ;;
 ;; 27-04-98 HS: fixed a bug with the minibuffer history. Thanks to
 ;;          Sam Mikes <smikes@alumni.hmc.edu> for pointing out the
-;;          existance of `minibuffer-history-minimum-string-length'
+;;          existence of `minibuffer-history-minimum-string-length'
 ;;
 ;; 19-05-98 HS: changed #' to (function ... in order to make it work
 ;;          with older emacsen. `minibuffer-history-minimum-string-length'
@@ -124,6 +124,7 @@
 ;; needed things
 (require 'cl)
 (require 'browse-url)
+(autoload 'url-retrieve "url")
 
 (when (not *cltl2-use-url*)
    (require 'url))
